==> atlantic-2.0.1-sources.jar: org/mule/commons/atlantic/lambda/consumer/DecaConsumer.java <==
package org.mule.commons.atlantic.lambda.consumer;

import org.mule.commons.atlantic.lambda.function.DecaFunction;

/**
 * Represents an operation that accepts ten input arguments and returns no result.  This is the ten-arity
 * specialization of {@link Consumer}.
 * Unlike most other functional interfaces, {@code DecaConsumer} is expected to operate via side-effects.
 *
 * This is a functional interface whose functional method is {@link #accept(Object, Object, Object, Object, Object, Object, Object, Object, Object, Object)}.
 *
 * @param <A> The type of the first argument to the operation.
 * @param <B> The type of the second argument to the operation.
 * @param <C> The type of the third argument to the operation.
 * @param <D> The type of the fourth argument to the operation.
 * @param <E> The type of the fifth argument to the operation.
 * @param <F> The type of the sixth argument to the operation.
 * @param <G> The type of the seventh argument to the operation.
 * @param <H> The type of the eighth argument to the operation.
 * @param <I> The type of the ninth argument to the operation.
 * @param <J> The type of the tenth argument to the operation.
 */
@FunctionalInterface
public interface DecaConsumer<A, B, C, D, E, F, G, H, I, J> extends AtlanticConsumer<DecaFunction<A, B, C, D, E, F, G, H, I, J, Void>> {

    /**
     * Performs this operation on the given arguments.
     *
     * @param a The first input argument.
     * @param b The second input argument.
     * @param c The third input argument.
     * @param d The fourth input argument.
     * @param e The fifth input argument.
     * @param f The sixth input argument.
     * @param g The seventh input argument.
     * @param h The eighth input argument.
     * @param i The ninth input argument.
     * @param j The tenth input argument.
     * @throws Throwable Any exception that the operation will throw.
     */
    void accept(A a, B b, C c, D d, E e, F f, G g, H h, I i, J j) throws Throwable;

    @Override
    default DecaFunction<A, B, C, D, E, F, G, H, I, J, Void> toFunction() {
        return (a, b, c, d, e, f, g, h, i, j) -> {
            accept(a, b, c, d, e, f, g, h, i, j);
            return null;
        };
    }
}

==> atlantic-3.0.0-sources.jar: org/mule/commons/atlantic/lambda/consumer/DecaConsumer.java <==
package org.mule.commons.atlantic.lambda.consumer;

import org.mule.commons.atlantic.lambda.function.DecaFunction;
import org.mule.commons.atlantic.lambda.supplier.Supplier;

/**
 * Represents an operation that accepts ten input arguments and returns no result.  This is the ten-arity
 * specialization of {@link Consumer}.
 * Unlike most other functional interfaces, {@code DecaConsumer} is expected to operate via side-effects.
 *
 * This is a functional interface whose functional method is {@link #accept(Object, Object, Object, Object, Object, Object, Object, Object, Object, Object)}.
 *
 * @param <A> The type of the first argument to the operation.
 * @param <B> The type of the second argument to the operation.
 * @param <C> The type of the third argument to the operation.
 * @param <D> The type of the fourth argument to the operation.
 * @param <E> The type of the fifth argument to the operation.
 * @param <F> The type of the sixth argument to the operation.
 * @param <G> The type of the seventh argument to the operation.
 * @param <H> The type of the eighth argument to the operation.
 * @param <I> The type of the ninth argument to the operation.
 * @param <J> The type of the tenth argument to the operation.
 */
@FunctionalInterface
public interface DecaConsumer<A, B, C, D, E, F, G, H, I, J> extends AtlanticConsumer<A, NonaConsumer<B, C, D, E, F, G, H, I, J>, DecaFunction<A, B, C, D, E, F, G, H, I, J, Void>> {

    @Override
    default NonaConsumer<B, C, D, E, F, G, H, I, J> downgrade(Supplier<A> supplier) {
        return (b, c, d, e, f, g, h, i, j) -> accept(supplier.get(), b, c, d, e, f, g, h, i, j);
    }

    /**
     * Performs this operation on the given arguments.
     *
     * @param a The first input argument.
     * @param b The second input argument.
     * @param c The third input argument.
     * @param d The fourth input argument.
     * @param e The fifth input argument.
     * @param f The sixth input argument.
     * @param g The seventh input argument.
     * @param h The eighth input argument.
     * @param i The ninth input argument.
     * @param j The tenth input argument.
     * @throws Throwable Any exception that the operation will throw.
     */
    void accept(A a, B b, C c, D d, E e, F f, G g, H h, I i, J j) throws Throwable;

    @Override
    default DecaFunction<A, B, C, D, E, F, G, H, I, J, Void> toFunction() {
        return (a, b, c, d, e, f, g, h, i, j) -> {
            accept(a, b, c, d, e, f, g, h, i, j);
            return null;
        };
    }
}
